=== modified file 'Makefile'
--- Makefile	2008-10-24 11:26:06 +0000
+++ Makefile	2008-12-15 15:05:04 +0000
@@ -4,7 +4,7 @@
 PYTHON_VERSION=2.4
 PYTHON=python${PYTHON_VERSION}
 IPYTHON=$(PYTHON) $(shell which ipython)
-PYTHONPATH:=$(shell pwd)/lib:$(shell pwd)/lib/mailman:${PYTHONPATH}
+PYTHONPATH:=$(PWD)/lib:$(PWD)/lib/mailman:${PYTHONPATH}
 VERBOSITY=-vv
 
 TESTFLAGS=-p $(VERBOSITY)
@@ -22,7 +22,9 @@
 CODEHOSTING_ROOT=/var/tmp/bazaar.launchpad.dev
 
 XSLTPROC=xsltproc
-WADL_FILE = ./lib/canonical/launchpad/apidoc/wadl-$(LPCONFIG).xml
+WADL_FILE = lib/canonical/launchpad/apidoc/wadl-$(LPCONFIG).xml
+WADL_XSL = lib/launchpadlib/wadl-to-refhtml.xsl
+API_INDEX = lib/canonical/launchpad/apidoc/index.html
 
 APPSERVER_ENV = \
   LPCONFIG=${LPCONFIG} \
@@ -35,16 +37,19 @@
 schema: build clean_codehosting
 	$(MAKE) -C database/schema
 	$(PYTHON) ./utilities/make-dummy-hosted-branches
-	rm -rf /var/tmp/fatsam
+	$(RM) -r /var/tmp/fatsam
 
 newsampledata:
 	$(MAKE) -C database/schema newsampledata
 
 $(WADL_FILE): bzr-version-info.py
-	LPCONFIG=$(LPCONFIG) $(PYTHON) ./utilities/create-lp-wadl.py | \
-		tee $(WADL_FILE) | \
-		$(XSLTPROC) ./lib/launchpadlib/wadl-to-refhtml.xsl - \
-		> ./lib/canonical/launchpad/apidoc/index.html
+	LPCONFIG=$(LPCONFIG) $(PYTHON) \
+	    ./utilities/create-lp-wadl.py > $(WADL_FILE)
+
+$(API_INDEX): $(WADL_FILE) $(WADL_XSL)
+	$(XSLTPROC) $(WADL_XSL) $(WADL_FILE) > $@
+
+apidoc: $(API_INDEX)
 
 check_launchpad_on_merge: build dbfreeze_check check check_sourcecode_dependencies
 
@@ -115,7 +120,7 @@
 
 inplace: build
 
-build: bzr-version-info.py compile $(WADL_FILE)
+build: bzr-version-info.py compile apidoc
 
 compile:
 	${SHHH} $(MAKE) -C sourcecode build PYTHON=${PYTHON} \
@@ -148,18 +153,18 @@
 	    $(PYTHON) test.py -f $(TESTFLAGS) $(TESTOPTS)
 
 run: inplace stop
-	rm -f thread*.request
+	$(RM) thread*.request
 	$(APPSERVER_ENV) $(PYTHON) -t $(STARTSCRIPT) \
 		 -r librarian,google-webservice -C $(CONFFILE)
 
 start-gdb: inplace stop support_files
-	rm -f thread*.request
+	$(RM) thread*.request
 	$(APPSERVER_ENV) nohup gdb -x run.gdb --args $(PYTHON) -t $(STARTSCRIPT) \
 		-r librarian,google-webservice -C $(CONFFILE) \
 		> ${LPCONFIG}-nohup.out 2>&1 &
 
 run_all: inplace stop sourcecode/launchpad-loggerhead/sourcecode/loggerhead
-	rm -f thread*.request
+	$(RM) thread*.request
 	$(APPSERVER_ENV) $(PYTHON) -t $(STARTSCRIPT) \
 		 -r librarian,buildsequencer,sftp,mailman,codebrowse,google-webservice \
 		 -C $(CONFFILE)
@@ -173,7 +178,8 @@
 	# Build rewrite map that maps friendly branch names to IDs. Necessary
 	# for http access to branches and for the branch scanner.
 	mkdir -p $(CODEHOSTING_ROOT)/config
-	$(PYTHON) cronscripts/supermirror_rewritemap.py $(CODEHOSTING_ROOT)/config/launchpad-lookup.txt
+	$(PYTHON) cronscripts/supermirror_rewritemap.py \
+		$(CODEHOSTING_ROOT)/config/launchpad-lookup.txt
 
 scan_branches: rewritemap
 	# Scan branches from the filesystem into the database.
@@ -211,7 +217,7 @@
 	    utilities/killservice.py librarian buildsequencer launchpad mailman
 
 shutdown: scheduleoutage stop
-	rm -f +maintenancetime.txt
+	$(RM) +maintenancetime.txt
 
 scheduleoutage:
 	echo Scheduling outage in ${MINS_TO_SHUTDOWN} mins
@@ -235,30 +241,30 @@
 		    app = Application('Data.fs', 'site.zcml')()"
 
 clean:
-	(cd sourcecode/pygettextpo; make clean)
-	find . -type f \( -name '*.o' -o -name '*.so' \
-	    -o -name '*.la' -o -name '*.lo' \
-	    -o -name '*.py[co]' -o -name '*.dll' \) -exec rm -f {} \;
-	rm -rf build
-	rm -f thread*.request
-	rm -rf lib/mailman /var/tmp/mailman/* /var/tmp/fatsam.appserver
-	rm -rf $(CODEHOSTING_ROOT)
-	-rm $(WADL_FILE)
-	-rm bzr-version-info.py
+	$(MAKE) -C sourcecode/pygettextpo clean
+	find . -type f \( \
+	    -name '*.o' -o -name '*.so' -o -name '*.la' -o \
+	    -name '*.lo' -o -name '*.py[co]' -o -name '*.dll' \) \
+	    -print0 | xargs -r0 $(RM)
+	$(RM) -r build
+	$(RM) thread*.request
+	$(RM) -r lib/mailman /var/tmp/mailman/* /var/tmp/fatsam.appserver
+	$(RM) -r $(CODEHOSTING_ROOT)
+	$(RM) $(WADL_FILE) $(API_INDEX)
+	$(RM) bzr-version-info.py
 
 realclean: clean
-	rm -f TAGS tags
-	$(PYTHON) setup.py clean -a
+	$(RM) TAGS tags
 
 clean_codehosting:
-	rm -rf $(CODEHOSTING_ROOT)
+	$(RM) -r $(CODEHOSTING_ROOT)
 	mkdir -p $(CODEHOSTING_ROOT)/mirrors
 	mkdir -p $(CODEHOSTING_ROOT)/push-branches
 	mkdir -p $(CODEHOSTING_ROOT)/config
 	touch $(CODEHOSTING_ROOT)/config/launchpad-lookup.txt
 
 zcmldocs:
-	PYTHONPATH=`pwd`/src:$(PYTHONPATH) $(PYTHON) \
+	PYTHONPATH=$(PWD)/src:$(PYTHONPATH) $(PYTHON) \
 	    ./sourcecode/zope/configuration/stxdocs.py \
 	    -f ./src/zope/app/meta.zcml -o ./doc/zcml/namespaces.zope.org
 

